<template>
  <div class="policy-info">
    <el-form ref="demoFormRef" :disabled="disabled" :model="documentsInfoForm" class="dialog_form">
      <el-row :gutter="0">
        <el-col :span="20">
          <el-form-item label="附件:" label-width="100px" prop="appendix" style="width: 100%">
            <div style="display: flex;gap: 10px">
              <file-upload v-model="documentsInfoForm.fileList"
                           :fileType="accept"
                           :isShowTip="false"/>
              <div v-if="documentsInfoForm.fileList.length === 0" style="color: #a9afbc">支持上传PDF格式文件</div>
            </div>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
  </div>
</template>

<script>

import {
  addProjectInvestmentFunding,
  editProjectInvestmentFunding,
  getProjectInvestmentFundingById
} from "@/api/projectEngineering/projectInvestmentFunding";
import Cookies from "js-cookie";
import {addDocumentInfo, getDocumentInfoById} from "@/api/projectEngineering/projectInfo";

export default {
  props: {
    disabled: {
      required: true,
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      documentsInfoForm: {
        fileList: [],
        projectId: ''
      },
      projectForm: {},
      accept: ['pdf'],
    };
  },
  methods: {
    getDocumentsInfo() {
      getDocumentInfoById(this.documentsInfoForm.projectId).then(res => {
        this.documentsInfoForm = res.data;
        if(!this.documentsInfoForm.fileList) {
          this.documentsInfoForm.fileList = []
        }
      });
    },
    submit() {
      if (!this.projectForm.id) {
        this.$message.error("请先保存投资管理基本信息")
      } else {
        this.documentsInfoForm.projectId = this.projectForm.id;
        addDocumentInfo(this.documentsInfoForm).then(response => {
          this.$modal.msgSuccess("提交成功");
        });
      }
    },
  },
  mounted() {
    this.documentsInfoForm.projectId = this.$route.query.projectId;
    const documentsInfoForm = Cookies.get("documentsInfoForm");
    const projectForm = Cookies.get("projectForm");

    const parsedDocumentsInfoForm = documentsInfoForm ? JSON.parse(documentsInfoForm) : null;
    const parsedProjectForm = projectForm ? JSON.parse(projectForm) : null;
    if (parsedDocumentsInfoForm) {
      this.documentsInfoForm = parsedDocumentsInfoForm
    }
    if (parsedProjectForm) {
      this.projectForm = parsedProjectForm
    }
    // 如果路由存在id且没有缓存,视为编辑或查看，调用api
    if (this.documentsInfoForm.projectId && !parsedDocumentsInfoForm) {
      this.getDocumentsInfo();
    }
  },
  beforeDestroy() {
    Cookies.set("documentsInfoForm", JSON.stringify(this.documentsInfoForm));
  },

};
</script>

<style lang="scss" scoped>
.item {
  width: 100%;
}

.documents-info-items {
  display: inline-block;
  width: 100%;
  height: 130px;
  border: 1px solid #dbdeea;
  background-color: #f3f7fc;

  .upload-files-items {
    margin-top: 10px;
    margin-left: 50px;
  }
}

.input-row {
  display: flex;
  width: 100%;

  .input-item {
    width: 100%;
  }
}

</style>
